@@ -1,4 +1,5 @@
-from py42._compat import str
+import json
+
 from py42.exceptions import Py42BadRequestError
 from py42.exceptions import Py42InvalidPageTokenError
 from py42.services import BaseService
@@ -16,20 +17,25 @@ class FileEventService(BaseService):
         `REST Documentation <https://forensicsearch-east.us.code42.com/forensic-search/queryservice/swagger-ui.html#/file-event-controller/searchEventsUsingPOST>`__
 
         Args:
-            query (:class:`~py42.sdk.queries.fileevents.file_event_query.FileEventQuery` or str):
+            query (:class:`~py42.sdk.queries.fileevents.file_event_query.FileEventQuery` or str or unicode):
                 A composed :class:`~py42.sdk.queries.fileevents.file_event_query.FileEventQuery`
                 object or the raw query as a JSON formatted string.
 
         Returns:
             :class:`py42.response.Py42Response`: A response containing the query results.
         """
+
+        if isinstance(query, str):
+            query = json.loads(query)
+        else:
+            query = dict(query)
+
         try:
-            query_str = str(query)
-            uri = u"/forensic-search/queryservice/api/v1/fileevent"
-            return self._connection.post(uri, data=query_str)
+            uri = "/forensic-search/queryservice/api/v1/fileevent"
+            return self._connection.post(uri, json=query)
         except Py42BadRequestError as err:
-            if u"INVALID_PAGE_TOKEN" in str(err.response.text):
-                page_token = query.page_token
+            if "INVALID_PAGE_TOKEN" in str(err.response.text):
+                page_token = query.get("pgToken")
                 if page_token:
                     raise Py42InvalidPageTokenError(err, page_token)
             raise
@@ -43,5 +49,5 @@ class FileEventService(BaseService):
         Returns:
             :class:`py42.response.Py42Response`: A response containing file details.
         """
-        uri = u"/forensic-search/queryservice/api/v1/filelocations"
-        return self._connection.get(uri, params={u"sha256": checksum})
+        uri = "/forensic-search/queryservice/api/v1/filelocations"
+        return self._connection.get(uri, params={"sha256": checksum})
